resolve_targets

Function resolve_targets 

pub(crate) fn resolve_targets(
    state: &CombatState,
    source: ActorId,
    shape: &ResolvedTargetShape,
    filter: &CandidateFilter,
    line_of_sight: LineOfSightPolicy,
    now: SimTime,
) -> Result<Vec<EnemyIdx>, TargetShapeError>
Resolve a combat target shape into its deterministic hit order.

Errors

Returns TargetShapeError when the shape, anchor, source, or spatial query is invalid.